==> nextcloud-app-news-13.1.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/es_419.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "¡Se presentó una falla en la solicitud, la conexión a la red no está disponible!",
    "Request unauthorized. Are you logged in?" : "Solicitud no autorizada. ¿Has iniciado sesisón?",
    "Request forbidden. Are you an admin?" : "Solicitud prohibida. ¿Eres un adminsitrador?",
    "Token expired or app not enabled! Reload the page!" : "¡La ficha expiró o la aplicación no está habilitada! ¡Por favor recarga la página!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "¡Se presentó un error interno del servidor! ¡Por favor verifica el archivo data/nextcloud.log para más informacón!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "¡Se presentó una falla en la solicitud, por el momento Nextcloud se encuentra en modo mantenimiento!",
    "Can not add feed: Exists already" : "No es posible agregar la fuente: ya existe",
    "Articles without feed" : "Artículos sin fuente",
    "Can not add folder: Exists already" : "No se puede agregar la carpeta: ya existe",
    "News" : "Noticias",
    "Use system cron for updates" : "Usa el cron del sistema para las actualizaciones",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Deshabilita esto si usas un actualizador personalizado como el actualizador de Python en la aplicación",
    "Purge interval" : "Intervalo de purga",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Número mínimo de segundos a esperar antes de eliminar de la base de datos carpetas y fuentes borrados; valores inferiores a 60 segundos son ignorados",
    "Maximum read count per feed" : "Conteo máximo de lecturas por fuente",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off" : "Define el número máximo de artículos que pueden ser leídos por fuente que no serán borrados por el trabajo de limpieza; si reaparecen artículos anteriores después de ser leídos, incrementa este valor; valores negativos tales como -1 desactivarán esta funcionalidad. ",
    "Maximum redirects" : "Redirecciones máximas",
    "How many redirects the feed fetcher should follow" : "Cuantas redirecciones debería seguir el buscador de fuentes",
    "Maximum feed page size" : "Tamaño máximo de la página de la fuente",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Tamaño máximo de una fuente en bytes. Si la página RSS/Atom es mayor a este valor, la actualización será abortada ",
    "Feed fetcher timeout" : "Tiempo de vida para el buscador de fuentes",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Número máximo de segundos a esperar a que cargue una fuente RSS o Atom; si toma más tiempo, será abortada",
    "Explore Service URL" : "Explorar la URL del Servicio",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Si es proporcionado, la URL de este servicio será consultada para desplegar las fuentes en la seccion de explorar fuente. Para regresar al servicio integrado de exploración, déjalo vacío",
    "For more information check the wiki" : "Para más información consulta el wiki",
    "Saved" : "Guardado",
    "Download" : "Descargar",
    "Close" : "Cerrar",
    "filter" : "filtro",
    "Language" : "Idioma",
    "Subscribe" : "Suscribir",
    "Got more awesome feeds? Share them with us!" : "¿Cuentas con más fuentes increíbles? ¡Compártelas con nosotros!",
    "No articles available" : "No hay artículos disponibles",
    "No unread articles available" : "No hay artículos sin leer disponibles",
    "Open website" : "Abrir sitio web",
    "Star article" : "Marcar el artículo",
    "Unstar article" : "Desmarcar artículo",
    "Keep article unread" : "Mantener el artículo como no-leído",
    "Remove keep article unread" : "Eliminar mantener artículo como no leído",
    "by" : "por",
    "from" : "de",
    "Play audio" : "Reproducir audio",
    "Download video" : "Descargar video",
    "Download audio" : "Descargar audio",
    "Keyboard shortcut" : "Atajo del teclado",
    "Description" : "Descripción",
    "right" : "derecha",
    "Jump to next article" : "Ir al artículo siguiente ",
    "left" : "izquierda",
    "Jump to previous article" : "Ir al artículo anterior",
    "Toggle star article" : "Alternar artículos marcados",
    "Star article and jump to next one" : "Marcar el artículo y continuar al siguiente",
    "Toggle keep current article unread" : "Alternar mantener artículo actual como no leído",
    "Open article in new tab" : "Abrir el artículo en una nueva pestaña",
    "Toggle expand article in compact view" : "Alternar expandir artículo en vista compacta",
    "Refresh" : "Actualizar",
    "Load next feed" : "Cargar la siguiente fuente ",
    "Load previous feed" : "Cargar fuente anterior",
    "Load next folder" : "Cargar la siguiente carpeta",
    "Load previous folder" : "Cargar carpeta anterrior",
    "Scroll to active navigation entry" : "Desplázate hasta el elemento de navegación activo",
    "Focus search field" : "Ir al campo de búsqueda",
    "Mark current article's feed/folder read" : "Marcar la fuente/carpeta del artículo actual como leído",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "¡Se ha detectado el modo Ajax o webron! ¡Tus fuentes no serán actualizadas!",
    "How to set up the operating system cron" : "Cómo establecer las tareas programadas del sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instala y configura un actualizador en paralelo más rápido que use el API de actualización de la nueva aplicación",
    "Non UTF-8 charset for MySQL/MariaDB database detected!" : "¡Se ha detectado un juego de caracteres no UTF-8 para la base de datos MySql/MariaDB!",
    "Learn how to convert your database to utf8mb4 (make a backup beforehand)" : "Descubre como convertir tu base de datos a utf8mb4 (haz un respaldo de antemano)",
    "Web address" : "Dirección web",
    "Feed exists already!" : "¡La fuente ya existe!",
    "Folder" : "Carpeta",
    "No folder" : "No hay carpetas",
    "New folder" : "Carpeta nueva ",
    "Folder name" : "Nombre de la carpeta",
    "Go back" : "Regresar",
    "Folder exists already!" : "¡La carpeta ya existe!",
    "Credentials" : "Credenciales",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "¡Las credenciales HTTP Basic Auth deben ser almacenadas decriptadas! ¡Todos aquellos que tengan acceso al servidor o a la base de datos tendrán acceso a ellas!",
    "Username" : "Usuario",
    "Password" : "Contraseña",
    "New Folder" : "Carpeta Nueva",
    "Create" : "Crear",
    "Explore" : "Explorar",
    "Update failed more than 50 times" : "La carga falló más de 50 veces",
    "Deleted feed" : "Borrar fuente",
    "Undo delete feed" : "Deshacer borrar fuente",
    "Rename" : "Renombrar",
    "Menu" : "Menú",
    "Mark read" : "Marcar como leído",
    "Unpin from top" : "Desanclar a la parte superior",
    "Pin to top" : "Anclar a la parte superior",
    "Newest first" : "Más reciente primero",
    "Oldest first" : "Más antiguo primero",
    "Default order" : "Ordenamiento predeterminado",
    "Enable full text" : "Habilitar texto completo",
    "Disable full text" : "Deshabilitar texto completo",
    "Unread updated" : "No-leídos actualizados",
    "Ignore updated" : "Ignorar actualizados",
    "Open feed URL" : "Abrir URL de la fuente",
    "Delete" : "Borrar",
    "Dismiss" : "Descartar",
    "Collapse" : "Colapsar",
    "Deleted folder" : "Borrar carpeta",
    "Undo delete folder" : "Deshacer borrar carpeta",
    "Starred" : "Marcados",
    "Unread articles" : "Artículos sin leer",
    "All articles" : "Todos los artículos",
    "Settings" : "Configuraciones ",
    "Disable mark read through scrolling" : "Deshabilitar el marcar como leído al desplazar",
    "Compact view" : "Vista compacta",
    "Expand articles on key navigation" : "Expandir artículos al navegar con el teclado",
    "Show all articles" : "Mostrar todos los artículos",
    "Reverse ordering (oldest on top)" : "Orden inverso (más antiguo arriba)",
    "Subscriptions (OPML)" : "Suscripciones (OPML)",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Error when importing: File does not contain valid OPML" : "Se presentó un error al importar: El archivo no contiene un OPML válido",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Se presentó un error al importar: OPML no contiene fuentes o carpetas",
    "Unread/Starred Articles" : "Artículos No Leídos/Marcados",
    "Error when importing: file does not contain valid JSON" : "Se presentó un error al importar: el archivo no contiene un JSON válido",
    "Help" : "Ayuda",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Documentation" : "Documentación",
    "Report a bug" : "Reportar una falla"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-news-18.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/es_419.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "¡Se presentó una falla en la solicitud, la conexión a la red no está disponible!",
    "Request unauthorized. Are you logged in?" : "Solicitud no autorizada. ¿Has iniciado sesisón?",
    "Request forbidden. Are you an admin?" : "Solicitud prohibida. ¿Eres un adminsitrador?",
    "Token expired or app not enabled! Reload the page!" : "¡La ficha expiró o la aplicación no está habilitada! ¡Por favor recarga la página!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "¡Se presentó un error interno del servidor! ¡Por favor verifica el archivo data/nextcloud.log para más informacón!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "¡Se presentó una falla en la solicitud, por el momento Nextcloud se encuentra en modo mantenimiento!",
    "Unread articles" : "Artículos sin leer",
    "News" : "Noticias",
    "Shared with me" : "Compartido conmigo",
    "Use system cron for updates" : "Usa el cron del sistema para las actualizaciones",
    "Purge interval" : "Intervalo de purga",
    "Maximum read count per feed" : "Conteo máximo de lecturas por fuente",
    "Maximum redirects" : "Redirecciones máximas",
    "Feed fetcher timeout" : "Tiempo de vida para el buscador de fuentes",
    "Explore Service URL" : "Explorar la URL del Servicio",
    "Saved" : "Guardado",
    "Download" : "Descargar",
    "Close" : "Cerrar",
    "No articles available" : "No hay artículos disponibles",
    "No unread articles available" : "No hay artículos sin leer disponibles",
    "Open website" : "Abrir sitio web",
    "Star article" : "Marcar el artículo",
    "Unstar article" : "Desmarcar artículo",
    "Keep article unread" : "Mantener el artículo como no-leído",
    "Remove keep article unread" : "Eliminar mantener artículo como no leído",
    "Share" : "Compartir",
    "Username" : "Usuario",
    "by" : "por",
    "from" : "de",
    "Play audio" : "Reproducir audio",
    "Download audio" : "Descargar audio",
    "Download video" : "Descargar video",
    "Keyboard shortcut" : "Atajo del teclado",
    "Description" : "Descripción",
    "right" : "derecha",
    "Jump to next article" : "Ir al artículo siguiente ",
    "left" : "izquierda",
    "Jump to previous article" : "Ir al artículo anterior",
    "Toggle star article" : "Alternar artículos marcados",
    "Star article and jump to next one" : "Marcar el artículo y continuar al siguiente",
    "Toggle keep current article unread" : "Alternar mantener artículo actual como no leído",
    "Open article in new tab" : "Abrir el artículo en una nueva pestaña",
    "Toggle expand article in compact view" : "Alternar expandir artículo en vista compacta",
    "Refresh" : "Actualizar",
    "Load next feed" : "Cargar la siguiente fuente ",
    "Load previous feed" : "Cargar fuente anterior",
    "Load previous folder" : "Cargar carpeta anterrior",
    "Load next folder" : "Cargar la siguiente carpeta",
    "Scroll to active navigation entry" : "Desplázate hasta el elemento de navegación activo",
    "Mark current article's feed/folder read" : "Marcar la fuente/carpeta del artículo actual como leído",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "¡Se ha detectado el modo Ajax o webron! ¡Tus fuentes no serán actualizadas!",
    "How to set up the operating system cron" : "Cómo establecer las tareas programadas del sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instala y configura un actualizador en paralelo más rápido que use el API de actualización de la nueva aplicación",
    "Subscribe" : "Suscribir",
    "Web address" : "Dirección web",
    "Feed exists already!" : "¡La fuente ya existe!",
    "Folder" : "Carpeta",
    "No folder" : "No hay carpetas",
    "New folder" : "Carpeta nueva ",
    "Folder name" : "Nombre de la carpeta",
    "Go back" : "Regresar",
    "Folder exists already!" : "¡La carpeta ya existe!",
    "Credentials" : "Credenciales",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "¡Las credenciales HTTP Basic Auth deben ser almacenadas decriptadas! ¡Todos aquellos que tengan acceso al servidor o a la base de datos tendrán acceso a ellas!",
    "Password" : "Contraseña",
    "New Folder" : "Carpeta Nueva",
    "Create" : "Crear",
    "Explore" : "Explorar",
    "Update failed more than 50 times" : "La carga falló más de 50 veces",
    "Deleted feed" : "Borrar fuente",
    "Undo delete feed" : "Deshacer borrar fuente",
    "Rename" : "Renombrar",
    "Menu" : "Menú",
    "Mark read" : "Marcar como leído",
    "Unpin from top" : "Desanclar a la parte superior",
    "Pin to top" : "Anclar a la parte superior",
    "Newest first" : "Más reciente primero",
    "Oldest first" : "Más antiguo primero",
    "Default order" : "Ordenamiento predeterminado",
    "Enable full text" : "Habilitar texto completo",
    "Disable full text" : "Deshabilitar texto completo",
    "Unread updated" : "No-leídos actualizados",
    "Ignore updated" : "Ignorar actualizados",
    "Open feed URL" : "Abrir URL de la fuente",
    "Delete" : "Borrar",
    "Dismiss" : "Descartar",
    "Collapse" : "Colapsar",
    "Deleted folder" : "Borrar carpeta",
    "Undo delete folder" : "Deshacer borrar carpeta",
    "Starred" : "Marcados",
    "All articles" : "Todos los artículos",
    "Settings" : "Configuraciones ",
    "Disable mark read through scrolling" : "Deshabilitar el marcar como leído al desplazar",
    "Compact view" : "Vista compacta",
    "Expand articles on key navigation" : "Expandir artículos al navegar con el teclado",
    "Show all articles" : "Mostrar todos los artículos",
    "Reverse ordering (oldest on top)" : "Orden inverso (más antiguo arriba)",
    "Subscriptions (OPML)" : "Suscripciones (OPML)",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Error when importing: File does not contain valid OPML" : "Se presentó un error al importar: El archivo no contiene un OPML válido",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Se presentó un error al importar: OPML no contiene fuentes o carpetas",
    "Unread/Starred Articles" : "Artículos No Leídos/Marcados",
    "Error when importing: file does not contain valid JSON" : "Se presentó un error al importar: el archivo no contiene un JSON válido",
    "Help" : "Ayuda",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Documentation" : "Documentación",
    "Report a bug" : "Reportar una falla"
},
"nplurals=2; plural=(n != 1);");
